@@ -40,10 +40,7 @@ namespace Beagle.Filters {
 	
 		public FilterChm () : base()
 		{
-		
-			RegisterSupportedTypes ();
 			SnippetMode = true;
-			
 		}
 		
 		override protected void DoOpen (FileInfo info) 
@@ -84,26 +81,17 @@ namespace Beagle.Filters {
 
 		override protected void DoPullProperties() 
 		{
-						
-			if(chmFile.Title != "") 
-				AddProperty (Beagle.Property.New ("dc:title", chmFile.Title));
-			
-						
+			AddProperty (Beagle.Property.New ("dc:title", chmFile.Title));
 		}
 
 		override protected void DoPull()
 		{
-			
-			
 			Finished ();
-			
-			
 		}
 
 		override protected void  DoClose() 
 		{
 			chmFile.Dispose ();
-		
 		}
 		
 		override protected  void  RegisterSupportedTypes()
