@@ -41,9 +41,6 @@ namespace Beagle.Daemon.EvolutionDataServerQueryable {
 
 	[QueryableFlavor (Name="EvolutionDataServer", Domain=QueryDomain.Local, RequireInotify=false)]
 	public class EvolutionDataServerQueryable : LuceneQueryable {
-		//private Scheduler.Priority priority = Scheduler.Priority.Immediate;
-		private Scheduler.Priority priority = Scheduler.Priority.Delayed;
-
 		private string photo_dir;
 
 		private bool initial_crawl = false;
@@ -83,6 +80,23 @@ namespace Beagle.Daemon.EvolutionDataServerQueryable {
 
 			bool success = false;
 
+			// FIXME: This is a total hack.  We call into a
+			// method inside libevolutionglue so that we can
+			// possibly catch a DllNotFoundException if it
+			// fails to load.  This is separate from the next
+			// try-catch-finally block, which calls into the
+			// e-d-s libraries.
+			try {
+				// This is a no-op
+				CalUtil.FreeGlueCompGLibSList (IntPtr.Zero);
+			} catch (DllNotFoundException ex) {
+				Logger.Log.Error (ex, "Unable to start EvolutionDataServer backend: Unable to find or open libraries:");
+				return;
+			} finally {
+				initial_crawl = false;
+				timer.Stop ();
+			}
+
 			// This is the first code which tries to open the
 			// evolution-data-server APIs.  Try to catch
 			// DllNotFoundException and bail out if things go
