@@ -25,6 +25,7 @@
 //
 
 using System;
+using Beagle.Util;
 
 namespace Beagle.Daemon {
 	
@@ -43,23 +44,37 @@ namespace Beagle.Daemon {
 		// EA nightmare scenario: a file whose permissions or ownership get
 		// changed after the EAs have been attached.  Thus attributes in
 		// the database always trump those found in EAs.
-		//
-		// FIXME: If we have write access to the path but it has attributes
-		// stored in the sqlite file attributes db, we should attach them
-		// to the file with EAs and delete the record from the db.
 
 		public FileAttributes Read (string path)
 		{
 			FileAttributes attr;
 			attr = store_sqlite.Read (path);
-			if (attr == null)
+
+			if (attr != null) {
+				// If we have write access to the path but it has attributes
+				// stored in the sqlite file attributes db, we should attach them
+				// to the file with EAs and delete the record from the db.
+
+				if (! FileSystem.IsWritable (path))
+					return attr;
+
+				bool success = store_ea.Write (attr);
+				if (success)
+					store_sqlite.Drop (path);
+			} else
 				attr = store_ea.Read (path);
 			return attr;
 		}
 
 		public bool Write (FileAttributes attr)
 		{
-			return store_ea.Write (attr) || store_sqlite.Write (attr);
+			if (store_ea.Write (attr)) {
+				// Drop any now-outdated information from the sqlite store.
+				store_sqlite.Drop (attr.Path);
+
+				return true;
+			} else
+				return store_sqlite.Write (attr);
 		}
 
 		public void Drop (string path)
