@@ -40,8 +40,6 @@ namespace Beagle.Daemon.KBookmarkQueryable {
 	[QueryableFlavor (Name="KonqBookmark", Domain=QueryDomain.Local, RequireInotify=false)]
 	public class KonqBookmarkQueryable : LuceneFileQueryable {
 
-		private static Logger log = Logger.Get ("KonqBookmarkQueryable");
-
 		private string konq_dir;
 		private string bookmark_file;
 		private Hashtable last_modified_table;
@@ -353,7 +351,7 @@ namespace Beagle.Daemon.KBookmarkQueryable {
 			if (current_bookmark.Info != null &&
 			    current_bookmark.Info.Metadata != null &&
 			    current_bookmark.Info.Metadata.TimeLastVisited != 0) {
-				DateTime date = new DateTime (1970, 1, 1);
+				DateTime date = DateTimeUtil.UnixToDateTimeUtc (0);
 				current_dt = date.AddSeconds (current_bookmark.Info.Metadata.TimeLastVisited);
 			} else
 				current_dt = file_last_write_time;
